@@ -4,7 +4,7 @@ from typing import Optional
 from requests import Response
 
 from coiote.utils import ApiEndpoint, StringResult, api_call, domain_header, sanitize_request_param, api_call_raw
-from coiote.v3.model.firmware_update import FirmwareConfigId, FirmwareUpdateConfig, FirmwareUpdateConfigCreateRequest, FirmwareUpdateConfigCreated
+from coiote.v3.model.firmware_update import FirmwareConfigId, FirmwareUpdateConfig, FirmwareUpdateConfigCreateRequest, FirmwareUpdateConfigCreated, ScheduledBasicFirmwareInfo
 
 
 class FirmwareUpdate(ApiEndpoint):
@@ -24,3 +24,11 @@ class FirmwareUpdate(ApiEndpoint):
     @api_call(FirmwareUpdateConfig)
     def get_update_configuration(self, id: FirmwareConfigId) -> Response:
         return self.session.get(self.get_url(f"/configurations/{id}"))
+
+    @api_call(ScheduledBasicFirmwareInfo)
+    def schedule_basic_firmware_upgrade(self, device_id: str, id: FirmwareConfigId, upgrade_name: str) -> Response:
+        payload = {
+            "fotaName": upgrade_name,
+            "fotaConfigId": id,
+        }
+        return self.session.post(self.get_url(f"/basic/{device_id}"), json=payload)
